#
# spec file for package nemo
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname  libnemo-extension
%define sover   1
%define typelib typelib-1_0-Nemo-3_0
Name:           nemo
Version:        3.2.2
Release:        1.1
Summary:        File browser for Cinnamon
License:        GPL-2.0+
Group:          System/GUI/Other
Url:            https://github.com/linuxmint/nemo
Source:         https://github.com/linuxmint/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM nemo-implicit-pointer-decl.patch marguerite@opensuse.org -- OBS gcc checks.
Patch1:         %{name}-implicit-pointer-decl.patch
# PATCH-FIX-UPSTREAM nemo-void-return-no-return.patch margueirte@opensuse.org -- Fix OBS gcc checks.
Patch2:         %{name}-void-return-no-return.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  cinnamon-translations
BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  python3-polib
BuildRequires:  shared-mime-info
BuildRequires:  tracker-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cinnamon-desktop)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12.0
BuildRequires:  pkgconfig(gtksourceview-2.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(x11)
Requires:       cinnamon-translations
Requires:       desktop-file-utils >= 0.7
Requires:       glib2-tools
Requires:       gvfs >= 1.3.2
Requires:       libcinnamon-desktop-data
Requires:       python3
Requires:       shared-mime-info >= 0.50
Recommends:     gdk-pixbuf-loader-rsvg
Recommends:     gvfs-backends
Suggests:       xdg-user-dirs
Suggests:       xplayer
Suggests:       xreader
Suggests:       xviewer
%glib2_gsettings_schema_requires

%description
Nemo is the file manager for the Cinnamon desktop environment.

%package devel
Summary:        Development files for Nemo
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{soname}%{sover} = %{version}
Requires:       %{typelib} = %{version}

%description devel
Nemo is the file manager for the Cinnamon desktop environment.

This package provides the development files for Nemo.

%package -n %{soname}%{sover}
Summary:        Nemo extension shared libraries
Group:          System/Libraries

%description -n %{soname}%{sover}
Nemo is the file manager for the Cinnamon desktop environment.

This package provides Nemo's shared libraries.

%package -n %{typelib}
Summary:        File Browser for Cinnamon -- Introspection Bindings
Group:          System/Libraries

%description -n %{typelib}
Nemo is the file manager for the Cinnamon desktop environment.

This package provides the GObject Introspection bindings for Nemo.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --libexecdir=%{_libexecdir}/%{name} \
  --disable-static                    \
  --disable-update-mimedb             \
  --enable-gtk-doc
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%suse_update_desktop_file %{name} System FileManager
%suse_update_desktop_file %{name}-autostart
%suse_update_desktop_file %{name}-autorun-software

# We need to own this directory.
mkdir -p %{buildroot}%{_libdir}/nemo/extensions-3.0/

%fdupes %{buildroot}%{_datadir}/

%post
%icon_theme_cache_post
%desktop_database_post
%mime_database_post
%glib2_gsettings_schema_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%mime_database_postun
%glib2_gsettings_schema_postun

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING* README.md debian/changelog
%{_bindir}/%{name}*
%{_libexecdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/%{name}*%{?ext_man}
%{_datadir}/dbus-1/services/org.Nemo.service
%{_datadir}/dbus-1/services/org.nemo.freedesktop.FileManager1.service
%{_datadir}/glib-2.0/schemas/org.nemo.gschema.xml
%{_datadir}/gtksourceview-?.0/language-specs/%{name}_action.lang
%{_datadir}/polkit-1/actions/org.nemo.root.policy

%files -n %{typelib}
%defattr(-,root,root)
%{_libdir}/girepository-1.0/Nemo-3.0.typelib

%files -n %{soname}%{sover}
%defattr(-,root,root)
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/extensions-3.0/
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{soname}.pc
%{_datadir}/gir-1.0/Nemo-3.0.gir
%{_datadir}/gtk-doc/html/libnemo-extension/

%changelog
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 3.2.2 (changes since 3.2.0):
  * Add missing "Desktop" DEBUG flag.
  * Add space to Name[en_GB].
  * file-operations: Don't recurse for trash operations.
  * Force X11 backend.
  * Remove screen metadata (we only ever have one screen).
  * nemo-file-operations.c: Don't update position metadata on most
    file operations - it's costly, and can cause lockups.
  * l10n: Generate additional files.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Migrate away from gnome-common deprecated vars and macros.
  * Fix GCC pointer signedness warnings.
  * Add a .view style class on the icon view scrolled window.
  * window: Remove a custom get_preferred_width/height implementation.
    We already take care of the default size when we create the
    window, and these only break assumptions of the default
    GtkWindow's handlers.
  * pathbar: Avoid GTK+ warnings.
  * pathbar: Remove a hardcoded width for sliders.
  * Close an open_as_root child on child exit.
  * nemo-context-menu-menu-item.c: Use correct grammar in the
    context menu toggle.
  * Fix a GTK+ 3.21.3+ desktop redraw issue (gh#linuxmint/nemo#1231).
  * Replace a deprecated gtk_icon_info_free() with g_object_unref().
  * file-operations: Reduce the time for reliable transfer rate.
  * Remove a 'Show text in icon' preference.
  * nemo-view.c: Unescape uris being passed to file-roller during
    drag-and-drop (replaces %%20 with spaces).
  * Expand grid width to canvas.
  * Minimum of one column.
  * Update nemo-file.c.
  * trash-monitor: Change trash monitoring process.
  * Fix --geometry option when Nemo is already running.
  * Keep warnings as warnings when building the packages.
  * nemo-window.c: Save sidebar width 100ms after last change.
  * nemo-application.c: Fix maximised window state preservation.
  * Remove conditional ellipsis code for GTK+ < 3.12.0 builds.
  * Bind double left click on blank to go to parent directory.
  * Add an option to manage double cick in blank area (off by
    default) because it changes previous behaviour.
  * nemo-file.c: Only append .desktop to desktop files when they
    actually need it. Trusted desktop files (ones that typically
    get made and placed on the desktop) don't show their extension,
    so when you try to rename them, the new name needs .desktop
    appended to it.
  * nemo-file-management-properties.glade: Improve the description
    of the click-to-rename feature.
  * nemo-thumbnails.c: Don't set a stack size.
  * nemo-application.c: Look for already-existing desktop windows
    before attempting to manage the desktop.
  * desktop: Don't rebuild the desktop any time _NET_WORKAREA
    changes - this can happen fairly frequently in some situations,
    causing crashes due to the asynchronous nature of nemo's
    directory loading back-end.
  * eel-gnome-extensions.c: Use preferred terminal emulator when
    using "Run in terminal" to execute something.
  * nemo-desktop-manager.c: Run layout_changed when the widget
    scale factor changes.
  * file-undo-operations: Change trashed files matching condition.
  * icon view: Use the correct container size for applying margins
    to the icon container. Also, make sure icon data is fully
    loaded before positioning items - desktop pseudo-items don't
    necessarily have the correct bounding boxes defined by the time
    layout occurs. Load this data just before trying to position
    the icon, rather than just after.
  * nemo-desktop-utils: Adjustments for Gtk 3.22 changes in monitor
    management. gdk_screen_get_monitor_workarea() no longer returns
    a valid workarea, it simply returns the geometry.
  * nemo-desktop-manager.c: Reload the desktop in an idle callback.
  * nemo-application.c: Add a whitelist for ignoring existing
    desktop handlers by WM_CLASS match. By default 'conky' is in
    the list.
- Remove nemo-fix-desktop-redraw.patch: fixed upstream.
- Move gtk-doc to the devel package.
- Update nemo-implicit-pointer-decl.patch and
  nemo-void-return-no-return.patch.
* Tue Sep 27 2016 sor.alexei@meowr.ru
- Add nemo-fix-desktop-redraw.patch from upstream commit 4e5a103:
  fix a GTK+ 3.21.3+ desktop (boo#1001431, gh#linuxmint/nemo#1231).
* Thu Jun 23 2016 sor.alexei@meowr.ru
- Update to version 3.0.6:
  * Generate action files manually (as opposed to during the build).
  * nemo-desktop-utils.c: return 0 for monitor index if a widget
    isn't realised (this can happen during configuration changes
    and during session startup).
  * nemo-desktop-icon-view.c: Disconnect from the same gsettings
    instance we connected to.
  * nemo-desktop-manager, nemo-application: Fix some cleanup
    issues - disconnect from the correct objects when disposing of
    the desktop manager, and destroy the desktop manager earlier
    in Nemo's destruction so there are no issues freeing the
    DesktopInfos.
  * notebook: Remove unused ifdef code.
  * nemo-list-view.c: Detach the column header menu from metadata
    when setting it up. Use the actual view's layout instead. When
    reacting to visible columns being changed, simplify things by
    iterating through the treeview column to build a new metadata
    list.
  * nemo-list-view.c: Don't show trash-specific columns in the
    header menu.
  * list view: Make changes to the search results view persistent.
    gvfs can't save metadata for the search 'folder' so we store it
    ourselves.
  * eel-canvas.c: Fix touchscreen selection in icon views.
* Wed Jun  1 2016 sor.alexei@meowr.ru
- Update to version 3.0.5 (changes since 3.0.3):
  * Add standard settings for EelEditableLabel.
  * Build-require cinnamon-translations.
  * Use g_hash_table_remove_all and get rid of some callbacks.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 3.0.3:
  * nemo-places-sidebar.c: When gtk overlay scrolling is in effect,
    add some padding right of the sidebar eject icons, otherwise
    they are covered by the scrollbar when it pops up.
  * Update pot file.
* Sat May 21 2016 mailaender@opensuse.org
- Update to version 3.0.2:
  * Fix build.
  * Fix action i18n scripts to write UTF-8.
  * nemo-icon-view: Include nemo-application.h needed in
    nemo_icon_view_add_file for: nemo_application_set_cache_flag,
    nemo_application_get_singleton.
  * nemo-pathbar: Use gint for slider_width instead of gint16
    silences an incorrect pointer type warning.
  * nemo-list-view.c: Don't explicitly unref columns anymore –
    they'll get handled when the tree view is destroyed.
  * nemo-icon-container.c: Re-enable desktop type-to-select feature.
    Also make a couple fixes on the positioning logic for this
    little popup. Where possible, it will avoid overlapping panels.
  * desktop windows: Maximise instead of relying on gdk for monitor
    workarea – it's inaccurate for anything but the primary monitor.
  * nemo-icon-container.c: Special case desktop windows for search
    popup – now that we can rely on the window being the correct
    size to account for panels, we can reliably position this popup
    off of those panels.
  * prefs: Don't try to hardcode a minimum size for the
    preferences dialog.
  * Use g_themed_icon_new instead of
    g_themed_icon_new_with_default_fallbacks.
  * nemo-window.c: As of 9cb9c48 we maximise the desktop
    containers to make sure they use the correct work area as set
    by muffin. This started causing the window state 'maximized'
    key to be set to true when opening a new nemo window.
    This corrects that issue, using disable_chrome as an indicator
    to ignore the window – only the desktop windows set this true.
* Thu May 12 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * pathbar: Always show the pathbar up and down arrows.
    Dynamically adding and removing these buttons was causing the
    visual style of buttons in the pathbar to break.
  * Fix segfault on changing the number of colums when in list view.
  * Fix uninitialised is_desktop flag.
  * Port Python scripts to Python 3.x: /data/extract_action_strings,
    /data/merge_action_strings,
    /files/usr/share/nemo/actions/myaction.py.
  * nemo-list-view.c:  Fix initial column sizing: expand the
    filename column only to fill available space.
    Other columns will start with their natural size.
  * nemo-view: Switch to nemo_get_file_by_uri so we don't get a null
    pointer if the file isn't already loaded internally.
  * Add desktop settings action.
  * nemo-places-sidebar.c: Ensure a minimum usable sidebar width
    when resizing windows or panes.
  * Set minimum size for File Management Preferences window.
  * Increase default width of File Management Preferences window.
  * nemo-list-view.c: Clean up column changes: only add columns and
    connect to them once, remove some unnecessary checks.
  * nemo-list-view.c: Give the name column a default width that
    the column-double-click autosize action can use. Otherwise it
    makes the name column as small as possible (the opposite what
    it's supposed to do, or what the other columns do).
  * Update m4 files.
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * Fix wrong desktop size on Gtk 3.20+.
  * Add missing includes.
  * Fix pointer types, to avoid warning.
  * Respect dbus_satisfied flag for menu enties on blank desktops.
  * Fix printf format specifier.
  * Don't draw the desktop on a cloned monitor.
  * Fix some missing cast warnings.
  * Fix fallback style for GTK 3.20+.
  * Add style class nemo-window-pane.
  * Add style class nemo-properties-dialog to GtkBuilder file.
  * Add style class in nemo_desktop_window_init (same as Nautilus).
  * Add style class to places sidebar.
  * Add style class to nemo-window.
  * Use a more specific class name for places sidebar.
  * nemo-icon-info.c: Remove invalid
    GTK_ICON_LOOKUP_GENERIC_FALLBACK flag (triggers warnings in
    Gtk 3.20+).
  * nemo-window: Add new flag NEMO_WINDOW_OPEN_FLAG_SEARCH and use
    the same slot if this flag is passed to
    nemo_window_slot_open_location_full to avoid opening a new
    window (and a crash) when starting a search with the open in
    new window preference enabled.
  * Updated makepot and pot file.
- Rebase nemo-void-return-no-return.patch.
* Wed Mar  9 2016 sor.alexei@meowr.ru
- Update to 2.8.7:
  * Improve context menu toggle:
  - shows separate distinct regions of the menu item now;
  - tooltip manifests as right-justified text next to the toggle
    icon.
  * Use g_strcmp0 instead of unsafe strcmp.
  * file: Don't crash when the original file path has reserved
    characters.
  * file-operations: Make sure to use correct filename when
    restoring from Trash.
  * file-utils: Ensure directories exist before restoring from trash.
* Fri Nov 27 2015 sor.alexei@meowr.ru
- Update to 2.8.6:
  * nemo-view.c: Fix Open context menu entry not updating its label
    when a new selection is made. Also, fix tracking the context
    toggle when the menu has scroll bars.
  * nemo-view: Fix invalid View reference when view types change,
    and the tooltip is updated for the context menu toggle.
* Fri Nov 20 2015 sor.alexei@meowr.ru
- Update to 2.8.5:
  * list view, icon view: Do not trigger click-on-rename until
    button release, in order to preserve the possibility of
    dragging an already-selected single item.
  * icon-view/container: Fix click-to-rename issue where selection
    count was not up-to-date, requiring an extra click to trigger
    a rename after selecting a single icon from having no selection
    previously.
  * bookmarks: Fix crashing and inconsistent behaviour when
    working with remote bookmarks.
  * nemo-icon-container: Prevent interactive search on the desktop.
* Thu Nov 12 2015 sor.alexei@meowr.ru
- Update to 2.8.4:
  * nemo-file-operations.c: Handle NULL NemoFiles when deciding
    queue: this happens in both directions when dragging/copying
    files to and from a Virtualbox guest or host.
  * Removed context menu option from preferences.
* Wed Nov 11 2015 sor.alexei@meowr.ru
- Update to 2.8.3:
  * Add control to context menu to toggle simple/complex menu.
  * nemo-list-view: Implement click-to-rename.
  * Remove nemo-directory-view-ui-light.xml (no longer needed).
  * Update pot file.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 2.8.2:
  * file operations queue: Refactor slightly to make it easier to
    manage what gets queued and what gets started immediately.
  * nemo-window-pane.c: Prevent search from appearing on desktop.
  * preferences: Move context menu toggle to the top of the
    Display page.
  * file operations window: Raise the window when another operation
    is added, if the window is visible (not status-iconed).
  * click-to-rename: move logic to earlier in the click event, in a
    way similar to how double-clicks are handled. Also, handle the
    preference change in nemo-view – this way it can be re-used
    later to handle list views as well. Also, this keeps us from
    interacting with GSettings so much.
  * icon view: Fetch click-to-rename preference when the view is
    loaded, do not allow click-to-rename on read-only files.
  * thumbnails: Detect and throttle back thumbnail generation for
    files that are being actively updated on disk.
  * file queue: Add some additional checks for determining whether
    or not to start a file operation immediately.
  * Add option to disable queueing.
  * job queue: Refactor to reduce duplication, add debugging info,
    add filesystem comparison to detect false "local" paths (local
    paths to non-local or non-native filesystems and mounts).
  * nemo-query-editor: Fix some casts to prevent build warnings.
  * click-to-rename: Fix accidental rename triggering with multiple
    selection in icon view
  * click-to-rename: Fix previous commit (broke double-click upon
    initial selection.)
  * list view: Do not clear the rename widget twice.
  * Fixed Nemo crashing when quickly clicking on two unmounted
    volumes in the sidebar.
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Update to 2.8.1:
  * nemo-list-view.c: Fix editable not being destroyed after a
    canceled rename in certain instances. This would cause the
    action bindings for cut/copy not to be released from the text
    entry box, breaking cut/copy/paste until Nemo is restarted.
  * src/nemo-extension-config-widget.c: Make "No extensions found"
    un-clickable like the other two lists.
* Wed Oct 21 2015 sor.alexei@meowr.ru
- Update to 2.8.0:
  * pathbar: use a private struct and use use
    nemo_is_[home/root/desktop]_directory().
  * Fix compile errors.
  * Don't use hardcoded script and action paths, remove unused sys
    script path.
  * Use definitions from nemo-global-preferences.
  * Move action key definition to nemo-action.h to be external
    usable.
  * Show comment as tooltips for actions in action config, and
    improve comments for some actions.
  * Remove nemo_window_slot_go_to().
  * Combine the search bar and query editor.
  * Add search_is_not_empty, to fixe a segfault in treelist.
  * Only include the domain if the method is SMB.
  * Bump some deps and build-deps.
  * Quick rename.
  * Fix default sort order bug in list view.
  * nemo-places-sidebar.c: Fix a couple of drag-and-drop issues
    when there are no bookmarks, or when the xdg-bookmark area is
    empty.
  * nemo-places-sidebar.c: Fix a memory leak.
  * connect-to-server: Remember the last connection type.
  * nemo-list-view.c: Fix column sorting when default sort type is
    "Detailed type".
  * nemo-connect-server-dialog.c: Fix previous commit.
  * Fix build warnings, missing prototype.
  * nemo-window-pane.c: Fix crash during location entry.
  * Fix indentation.
  * Don't assign the position of the last closed window to the
    first opened window (it would be really confusing if it worked…
    and it didn't really work since gtk_application_get_windows()
    seemed to also count the desktop window).
  * Prefs: Rephrase quickrename option.
  * nemo-action-config-widget.c: Localise non-localised comment
    strings.
  * Update pot file.
  * Re-add revealer animation on search bar.
  * Fix Query Editor Row not displaying.
- Fix dependencies.
- Rename and rebase nemo-2.4.0-void-return-no-return.patch to
  nemo-void-return-no-return.patch.
- Some cleanup.
* Mon Aug 10 2015 i@marguerite.su
- update version 2.6.7
  * progress window: simplify slightly, have info widgets
    manage themselves
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.5
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2.4.5
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
- drop support for openSUSE 12.3 which will be EOL soon
- drop patch: nemo-2.3.0-revert-hidpi-support.patch
- add patch: nemo-implicit-pointer-decl.patch
  * use strcmp without including string.h
* Tue Aug 12 2014 i@marguerite.su
- add patch: nemo-2.3.0-revert-hidpi-support.patch
  * revert Hi-DPI support on openSUSE 12.3, whose GTK+ doesn't
    support it
* Tue Jul 15 2014 i@marguerite.su
- update version 2.3.0
  * simplify button event handling for nemo panes
  * Don't switch the current tab on right-click events
  * rename function for relative tab reordering
* Wed Jul  9 2014 stefan@fam-elser.de
- update version 2.2.3
* Thu May 22 2014 stefan@fam-elser.de
- update version 2.2.2
* Fri May  2 2014 i@marguerite.su
- update version 2.2.1
* Sun Apr 20 2014 i@marguerite.su
- update version 2.2.0
- add patch: nemo-2.2.0-void-return-no-return.patch
* Tue Nov 26 2013 johann.luce@wanadoo.fr
- update version 2.0.8
  * Fix passing non-latin uri's to actions.
* Mon Nov 25 2013 johann.luce@wanadoo.fr
- update version 2.0.7
  * Revert "Use gksu instead of pkexec until systemd/glib/whatever is fixed."
  * Revert "Add a bit more space between items in the places sidebar"
  * Add a bit more space between items in the places sidebar
  * Don't show custom mimetype handlers in the menu.
  * Don't crash when browser mode is off and multiple folders are selected and opened.
  * Don't display actions for special items like desktop icons
  * list-view: prevent name column from shrinking to uselessness
  * Fix orphan tooltips in icon view and desktop when deleting items
  * Use gksu instead of pkexec until systemd/glib/whatever is fixed.
* Tue Nov 12 2013 johann.luce@wanadoo.fr
- update version 2.0.6
  * Fix action string script, update nemo action translations
* Mon Nov  4 2013 johann.luce@wanadoo.fr
- update version 2.0.5
  * When renaming test.folder in listview, select entire filename.
  * remove nemo-2.0.3-GTK_STOCK.patch
  * clean spec file
* Sat Nov  2 2013 i@marguerite.su
- update verson 2.0.4
  * Fix pathbar button middle-click action
* Mon Oct 28 2013 i@marguerite.su
- update version 2.0.3
  * Don't use g_list_copy_deep, it isn't supported in Mint 13
  * Unhide certain default mime actions from the open-with menu.
  * Add a shortcut to /usr/share/icons in the icon picker dialog
- drop patch: nemo-2.0.1-g_list_copy_deep.patch, upstreamed
* Mon Oct 21 2013 i@marguerite.su
- update version 2.0.1
  * see https://github.com/linuxmint/nemo/commits/master
- enable documentation
- remove lang_package, now cinnamon has a package called translation
- use gnome-common's version to wise detect Tumbleweed
- add patch: nemo-2.0.1-g_list_copy_deep.patch, fix g_list_copy_deep
- add patch: nemo-2.0.1-view-no-return.patch, fix OBS gcc checks
- add patch: nemo-2.0.1-GTK_STOCK.patch, GTK_STOCK_* deprecated
* Mon Nov 19 2012 nmo.marques@gmail.com
- Update to version 1.1.2
  + small fixes
* Wed Nov  7 2012 nmo.marques@gmail.com
- Add dbus-1 (directory ownership) and xz (unpack sources in 12.1)
  to BRs
* Tue Nov  6 2012 nmo.marques@gmail.com
- initial package from version 1.1.0
